@@ -158,6 +158,7 @@ class InternalDialog(BuilderDialog):
 
         if not active:
             if self._is_livepatch_supported() and \
+               self.settings_button and \
                self.settings.get_int('launch-count') >= 4:
                 self.set_desc(_("<b>Tip:</b> You can use Livepatch to "
                                 "keep your computer more secure between "
@@ -384,7 +385,7 @@ class NeedRestartDialog(InternalDialog):
             iface.RequestReboot()
         except dbus.DBusException:
             self._request_reboot_via_consolekit()
-        except Exception as e:
+        except Exception:
             pass
 
     def _request_reboot_via_consolekit(self):
@@ -397,7 +398,7 @@ class NeedRestartDialog(InternalDialog):
             iface.Restart()
         except dbus.DBusException:
             self._request_reboot_via_logind()
-        except Exception as e:
+        except Exception:
             pass
 
     def _request_reboot_via_logind(self):
