@@ -38,14 +38,14 @@ class HweSupportStatusTestCase(TestCase):
     )
 
     INSTALLED_UNSUPPORTED_HWE_PKG_NAMES = (
-        INSTALLED_UNSUPPORTED_HWE_KERNEL_PKG_NAMES +
-        INSTALLED_UNSUPPORTED_HWE_XORG_PKG_NAMES)
+        INSTALLED_UNSUPPORTED_HWE_KERNEL_PKG_NAMES
+        + INSTALLED_UNSUPPORTED_HWE_XORG_PKG_NAMES)
 
     def setUp(self):
         self.cache = []
-        INSTALL = (self.INSTALLED_UNSUPPORTED_HWE_PKG_NAMES +
-                   self.INSTALLED_SUPPORTED_HWE_PKG_NAMES +
-                   self.INSTALLED_OTHER_PKG_NAMES)
+        INSTALL = (self.INSTALLED_UNSUPPORTED_HWE_PKG_NAMES
+                   + self.INSTALLED_SUPPORTED_HWE_PKG_NAMES
+                   + self.INSTALLED_OTHER_PKG_NAMES)
         for name in INSTALL:
             self.cache.append(make_mock_pkg(name))
 
@@ -121,7 +121,7 @@ class HweSupportStatusTestCase(TestCase):
                 text = mock_print.call_args[0][0]
                 print("43242343243", mock_print.call_count)
                 self.assertIn(
-                    "Your system is supported until April 2023", text)
+                    "Your system is supported until April 2019", text)
 
     def test_advice_about_hwe_status_supported_hwe_stack(self):
         with patch("hwe_support_status.is_unsupported_hwe_running") as m:
@@ -139,7 +139,7 @@ class HweSupportStatusTestCase(TestCase):
                 text = mock_print.call_args[0][0]
                 self.assertIn(
                     "Your Hardware Enablement Stack (HWE) is supported "
-                    "until April 2023", text)
+                    "until April 2019", text)
 
 
 if __name__ == "__main__":
